import QtQuick 2.15

Item {
    id: root
    width: 480
    height: 272

    state: "idle_state"
    property int transitionTime: 350

    LowIdle {
        id: lowIdle
        watchText: OvenManager.watchString
        onStartSelected: root.state = "active_state"

        Behavior on opacity{
            NumberAnimation{
                duration: 700
                 easing.type: Easing.InQuart
            }
        }
    }

    LowActive {
        id: lowActive
        temperatureText: OvenManager.temperatureValue ? OvenManager.temperatureValue + "°" : "- -"
        timerText: OvenManager.timerString
        watchText: OvenManager.watchString

        onTemperatureSelected: root.state = "temperature_state"
        onTimerSelected: root.state = "timer_state"
        onProgramSelected: root.state = "program_state"
        onFunctionSelected: root.state = "function_state"
        onSettingsSelected: root.state = "settings_state"
        onPowerSelected: {
            OvenManager.reset()
            root.state = "idle_state"
        }

        Behavior on opacity{
            NumberAnimation{
                duration: 700
                easing.type: Easing.InQuart
            }
        }
    }


    LowFunction{
        id: lowFunction

        onCloseClicked:  root.state = "active_state"

        Behavior on x{
            NumberAnimation{
                duration: transitionTime
                easing.type: Easing.OutCirc
            }
        }
    }

    LowProgram{
        id: lowProgram

        currentProgram: OvenManager.currentProgram
        onCloseClicked: root.state = "active_state"
        onProgramSelected: OvenManager.setProgram(index)

        Behavior on x{
            NumberAnimation{
                duration: transitionTime
                easing.type: Easing.OutCirc
            }
        }
    }


    LowSettings{
        id: lowSettings
        onCloseClicked: root.state = "active_state"

        Behavior on x{
            NumberAnimation{
                duration: transitionTime
                easing.type: Easing.OutCirc
            }
        }
    }

    LowTemperature {
        id: lowTemperature
        temperature: OvenManager.temperatureValue
        onCloseClicked: root.state = "active_state"
        onTemperatureUpdated:  OvenManager.setTemperature(temperature+value)

        Behavior on angleDegree{
            NumberAnimation{
                duration: 350
                easing.type: Easing.OutCirc
            }
        }

        Behavior on temperature{
            NumberAnimation{
                duration: 550
                easing.type: Easing.Linear
            }
        }

        Behavior on y{
            NumberAnimation{
                duration: transitionTime
                easing.type: Easing.OutCirc
            }
        }

    }

    LowTimer {
        id: lowTimer
        timerText: OvenManager.timerString
        onCloseClicked:  root.state = "active_state"
        onTimeUpdated: OvenManager.addTime(value)
        onStartClicked: {
            OvenManager.setRunning(true)
            root.state = "active_state"

        }

        Behavior on y{
            NumberAnimation{
                duration: transitionTime
                easing.type: Easing.OutCirc
            }
        }

    }


    states: [
        State {
            name: "idle_state"

            PropertyChanges {
                target: lowIdle
                opacity: 1
            }

            PropertyChanges {
                target: lowActive
                opacity: 0
            }

            PropertyChanges {
                target: lowActive
                enabled: false
            }

            PropertyChanges {
                target: lowFunction
                x: root.width
            }

            PropertyChanges {
                target: lowProgram
                x: root.width
            }

            PropertyChanges {
                target: lowSettings
                x: root.width
            }

            PropertyChanges {
                target: lowTemperature
                y: root.height
            }

            PropertyChanges {
                target: lowTimer
                y: root.height
            }


        },
        State {
            name: "active_state"

            PropertyChanges {
                target: lowIdle
                opacity: 0
            }

            PropertyChanges {
                target: lowActive
                opacity: 1
            }

            PropertyChanges {
                target: lowActive
                enabled: true
            }

            PropertyChanges {
                target: lowFunction
                x: root.width
            }

            PropertyChanges {
                target: lowProgram
                x: root.width
            }

            PropertyChanges {
                target: lowSettings
                x: root.width
            }

            PropertyChanges {
                target: lowTemperature
                y: root.height
            }

            PropertyChanges {
                target: lowTimer
                y: root.height
            }

        },
        State {
            name: "function_state"
            extend: "active_state"
            PropertyChanges {
                target: lowFunction
                x: 0
            }
            PropertyChanges {
                target: lowActive
                enabled: false
            }

        },
        State {
            name: "program_state"
            extend: "active_state"
            PropertyChanges {
                target: lowProgram
                x: 0
            }
            PropertyChanges {
                target: lowActive
                enabled: false
            }

        },
        State {
            name: "settings_state"
            extend: "active_state"
            PropertyChanges {
                target: lowSettings
                x: 0
            }
            PropertyChanges {
                target: lowActive
                enabled: false
            }

        },

        State {
            name: "temperature_state"
            extend: "active_state"
            PropertyChanges {
                target: lowTemperature
                y: 0
            }
            PropertyChanges {
                target: lowActive
                enabled: false
            }

        },
        State {
            name: "timer_state"
            extend: "active_state"
            PropertyChanges {
                target: lowTimer
                y: 0
            }
            PropertyChanges {
                target: lowActive
                enabled: false
            }
        }


    ]





}
