#include "OvenManager.h"
#include <math.h>
#include <stdio.h>


OvenManager::OvenManager()
    :running(false), temperatureValue(0),  currentProgram(NONE), timerString("00:00"), watchString("17:00"), performanceEnabled(false)
{
    m_watch_time_value = 1020;
    m_watch_time_counter = 0;
    m_timer_value = 0;
    m_temperature_value = 0;
    m_timer.setInterval(1000);
    m_timer.setSingleShot(false);
    m_timer.onTimeout([this](){this->updateTimer();});
    m_timer.start();


}

void OvenManager::setRunning(bool value)
{
    running.setValue(value);

}


void OvenManager::updateTimer()
{
    if(running.value())
    {

        if((m_timer_value>0))
        {
            m_timer_value -=1;

            timerString.setValue(getTimerString(m_timer_value));
        }
        else
        {
            setRunning(false);
        }
    }

    m_watch_time_counter++;
    if(!(m_watch_time_counter%60))
    {
        m_watch_time_value++;
        if(m_watch_time_value>=1440)
            m_watch_time_value = 0;
        watchString.setValue(getTimerString(m_watch_time_value));
    }

}

void OvenManager::addTime(int value)
{
    m_timer_value += value;
    if(m_timer_value>MAX_TIMER_VALUE)
        m_timer_value = MAX_TIMER_VALUE;
    if(m_timer_value<MIN_TIMER_VALUE)
        m_timer_value = MIN_TIMER_VALUE;
    timerString.setValue(getTimerString(m_timer_value));
}

void OvenManager::setTemperature(int value)
{

    m_temperature_value = value;

    if(m_temperature_value<0)
        m_temperature_value = 0;
    if(m_temperature_value>MAX_TEMPERATURE)
        m_temperature_value = MAX_TEMPERATURE;

    temperatureValue.setValue(m_temperature_value);
}

void OvenManager::reset()
{
    running.setValue(false);
    m_timer_value = 0;
    timerString.setValue(getTimerString(m_timer_value));
    m_temperature_value = 0;
    temperatureValue.setValue(m_temperature_value);
    lightActive.setValue(false);
    grillActive.setValue(false);
    steamActive.setValue(false);
    defrostActive.setValue(false);
    cleanActive.setValue(false);
    lockActive.setValue(false);
    currentProgram.setValue(NONE);

}


std::string OvenManager::getTimerString(int totalsecs)
{
    int minutes = floor(totalsecs/60);
    int seconds = totalsecs%60;

    std::string minutes_string, seconds_string;
    if(minutes<10)
        minutes_string = "0"+std::to_string(minutes);
    else
        minutes_string = std::to_string(minutes);

    if(seconds<10)
        seconds_string = "0"+std::to_string(seconds);
    else
        seconds_string = std::to_string(seconds);


    return minutes_string+":"+seconds_string;

}

void OvenManager::setProgram(int value)
{

    if(currentProgram.value()==value)
        return;

    this->reset();


    switch (value)
    {
    case NONE:

        return;
        break;
    case CAKE:
        m_timer_value = 2700;
        m_temperature_value = 200;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(false);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case BREAD:
        m_timer_value = 3600;
        m_temperature_value = 275;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(false);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case PIZZA:
        m_timer_value = 900;
        m_temperature_value = 225;
        lightActive.setValue(false);
        grillActive.setValue(true);
        steamActive.setValue(false);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case FISH:
        m_timer_value = 1800;
        m_temperature_value = 175;
        lightActive.setValue(false);
        grillActive.setValue(true);
        steamActive.setValue(true);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case VEGGIE:
        m_timer_value = 600;
        m_temperature_value = 125;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(true);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case POULTRY:
        m_timer_value = 1200;
        m_temperature_value = 100;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(true);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case STEAM:
        m_timer_value = 480;
        m_temperature_value = 275;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(true);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case MEAT:
        m_timer_value = 1500;
        m_temperature_value = 175;
        lightActive.setValue(false);
        grillActive.setValue(true);
        steamActive.setValue(false);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case WARMER:
        m_timer_value = 300;
        m_temperature_value = 100;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(false);
        defrostActive.setValue(true);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case PRE_HEAT:
        m_timer_value = 240;
        m_temperature_value = 75;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(false);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case DELICATE:
        m_timer_value = 300;
        m_temperature_value = 50;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(false);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    case HIGH_FAN:
        m_timer_value = 180;
        m_temperature_value = 125;
        lightActive.setValue(false);
        grillActive.setValue(false);
        steamActive.setValue(false);
        defrostActive.setValue(false);
        cleanActive.setValue(false);
        lockActive.setValue(false);
        break;
    default:
        break;
    }

    timerString.setValue(getTimerString(m_timer_value));
    temperatureValue.setValue(m_temperature_value);
    currentProgram.setValue(value);
    running.setValue(true);
}



