#ifndef OVENMANAGER_H
#define OVENMANAGER_H

#include <qul/property.h>
#include <qul/singleton.h>
#include <qul/timer.h>
#include <string>

#define DEFAULT_TEMPERATURE 150
#define MAX_TEMPERATURE 275
#define MIN_TIMER_VALUE 0
#define MAX_TIMER_VALUE 5940


class OvenManager : public Qul::Singleton<OvenManager>
{
public:

    enum Program {CAKE, BREAD, PIZZA, FISH, VEGGIE, POULTRY, STEAM, MEAT, WARMER, PRE_HEAT, DELICATE, HIGH_FAN, NONE};

    OvenManager();

    Qul::Property<bool> running;
    Qul::Property<bool> lightActive;
    Qul::Property<bool> grillActive;
    Qul::Property<bool> steamActive;
    Qul::Property<bool> defrostActive;
    Qul::Property<bool> cleanActive;
    Qul::Property<bool> lockActive;
    Qul::Property<int> temperatureValue;
    Qul::Property<int> currentProgram;
    Qul::Property<std::string> timerString;
    Qul::Property<std::string> watchString;
    Qul::Property<bool> performanceEnabled;

    void setRunning(bool value);
    void updateTimer();
    void addTime(int value);
    void setTemperature(int value);
    void reset();
    std::string getTimerString(int seconds);
    void setProgram(int value);

private:
    int m_timer_value;
    int m_watch_time_value;
    int m_watch_time_counter;
    int m_temperature_value;
    Qul::Timer m_timer;
};

#endif // OVENMANAGER_H
